@@ -16,7 +16,7 @@ from pretty_tables import PrettyTables
 
 
 # app specific constants
-__version__ = (0, 1, 2)
+__version__ = (0, 1, 4)
 __app__ = "tl"
 
 # regular constants
@@ -234,6 +234,15 @@ WARNING: This tool is just a prototype of a rapid development process. The final
         help="Start or close a time recording",
     )
 
+    parser.add_argument(
+        '-d',
+        '--date',
+        nargs='?',
+        type=date.fromisoformat,
+        help="Define a workdate (Format: YYYY-MM-DD)",
+        default=date.fromisoformat(date.today().isoformat()),
+    )
+
     parser.add_argument(
         "-t",
         "--tags",
@@ -241,6 +250,11 @@ WARNING: This tool is just a prototype of a rapid development process. The final
         default=[],
     )
 
+    parser.add_argument(
+        "--git",
+        action=argparse.BooleanOptionalAction,
+    )
+
     return parser
 
 def format_stats(workdate: date, stats: Dict, timeformat: str = 'H', indentation: int = 4) -> str:
@@ -257,6 +271,7 @@ def format_stats(workdate: date, stats: Dict, timeformat: str = 'H', indentation
     :return: Formatted output that can be printed or written to file.
     :rtype: str
     """
+    # Highlight active recordings in the table.
     tags = list(stats.keys())
     tags.sort()
     vals = []
@@ -370,12 +385,18 @@ def main():
         if os.path.isfile(f):
             _cfg.append(f)
 
-    cfg = yacf.Configuration(*_cfg).load()
+    cfg = yacf.Configuration(*_cfg).load().dict()
     _cfg = ":".join(_cfg)
     log.debug(f"Loaded configuration from {_cfg}")
 
+    # postprocess configuration to include CLI options
+    if args.git is not None:
+        # TODO: Use yacf.configuration.set() as soon as it is available
+        cfg.get('git', {})['enabled'] = args.git
+
     # TODO: Make workdate configurable with a CLI option
-    workdate = date.today()
+    #workdate = date.today()
+    workdate = args.date
 
     path = os.path.join(
         cfg.get('database.directory'),
